@@ -1,7 +1,5 @@
 ##
-# Copyright 2012 Ghent University
-# Copyright 2012 Stijn De Weirdt
-# Copyright 2012 Kenneth Hoste
+# Copyright 2012-2013 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
@@ -28,6 +26,9 @@
 The toolchain module with the abstract Toolchain class.
 
 Creating a new toolchain should be as simple as possible.
+
+@author: Stijn De Weirdt (Ghent University)
+@author: Kenneth Hoste (Ghent University)
 """
 
 from vsc import fancylogger
@@ -86,7 +87,7 @@ class Toolchain(object):
 
     def base_init(self):
         if not hasattr(self, 'log'):
-            self.log = fancylogger.getLogger(self.__class__.__name__)
+            self.log = fancylogger.getLogger(self.__class__.__name__, fname=False)
 
         if not hasattr(self, 'options'):
             self.options = self.OPTIONS_CLASS()
